# python-test

**pkg-15903** is a python test program. It runs a http call against a url and return http status code.

```
$ pkg-15903 --url https://www.google.com
URL (https://www.google.com/) result: 200
```
